@@ -44,8 +44,8 @@
 #' @export
 #'
 #' @examples
-#' \donttest{
-#' if (!exists("ctstantestfit")) example(ctstantestfit)
+#' if(w32chk()){
+#'
 #' ctStanTIpredeffects(ctstantestfit,
 #'  whichpars=c('CINT','dtDIFFUSION[2,2]'), plot=TRUE)
 #' }
@@ -55,10 +55,13 @@ ctStanTIpredeffects<-function(fit,returndifference=FALSE, probs=c(.025,.5,.975),
   nsubjects=20,filter=NA,plot=FALSE){
 # browser()
   #get objects
+  # browser()
   ctspec <- fit$ctstanmodel$pars
   e<-ctExtract(fit)
   rawpopmeans <- e$rawpopmeans
-  tipreds<-ctCollapse(e$tipreds,1,mean) #maybe collapsing over sampled tipred values is not ideal?
+  if(fit$standata$nmissingtipreds){
+    tipreds<-ctCollapse(e$tipreds,1,mean) #maybe collapsing over sampled tipred values is not ideal?
+  } else tipreds <- fit$standata$tipredsdata
   
   #sample
   niter<-dim(e$rawpopmeans)[1]
@@ -206,7 +209,6 @@ ctStanTIpredeffects<-function(fit,returndifference=FALSE, probs=c(.025,.5,.975),
   out <- list(y=aperm(out, c(3,2,1)), x=tipreds[,1,drop=FALSE])
   
   # names(out)[[1]] <-
-  
   if(!plot) return(out) else {
     # dots <- list(...)
     # dots$input=out
